/*
 * Copyright 2018 NXP
 */
#ifndef __DDR_PERF_H
#define __DDR_PERF_H

/**
 * perf_event_pmu_is_available: Checks the existence of the @type PMU.
 */
uint32_t
perf_event_pmu_exist(const char *type);

/**
 * perf_event_pmu_get_type: Gets the type value specified in @type
 */
uint32_t
perf_event_pmu_get_type(const char *type);

/**
 * perf_event_pmu_get_event: gets the event value specified in @event_name
 */
uint32_t
perf_event_pmu_get_event(const char *type, const char *event_name);

/**
 * perf_event_pmu_config: Provides type and config besides pid and cpu
 * to return a fd for reading counter values.
 *
 * @type: the type which can be retrieved using perf_event_pmu_get_type()
 * @config: config which can be retrieved using perf_event_pmu_get_event()
 *
 * Note that this returns a file fd which perf_event_pmu_enable/reset/read can
 * be used. For multiple type/config you must call perf_event_pmu_config() and
 * store the fds probably into an arrray or some sort.
 */
int
perf_event_pmu_config(int pid, int cpu, uint32_t type, uint32_t config);

/**
 * perf_event_pmu_ddr_config: Just like perf_event_pmu_config() but for ddr
 * which we only do system-wide, so there's no need to specify either pid or
 * cpu.
 */
int
perf_event_pmu_ddr_config(uint32_t type, uint32_t config);

/**
 *
 * perf_event_pmu_reset: Reset it.
 */
void
perf_event_pmu_reset(int fd);

/**
 * perf_event_pmu_enable: Enable it.
 */
void
perf_event_pmu_enable(int fd);

/**
 * perf_event_pmu_disable: Disable it.
 */
void
perf_event_pmu_disable(int fd);

/**
 * perf_event_pmu_read: Returns the counter value specified using
 * perf_event_pmu_config() or perf_event_pmu_ddr_config().
 */
uint64_t
perf_event_pmu_read(int fd);


#endif
